Class: Aws::ResourceExplorer2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ResourceExplorer2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-resourceexplorer2/client.rb,
sig/client.rbs
Overview
An API client for ResourceExplorer2. To construct a client, you need to configure a :region and :credentials.
client = Aws::ResourceExplorer2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateDefaultViewResponseSuccess, _BatchGetViewResponseSuccess, _CreateIndexResponseSuccess, _CreateResourceExplorerSetupResponseSuccess, _CreateViewResponseSuccess, _DeleteIndexResponseSuccess, _DeleteResourceExplorerSetupResponseSuccess, _DeleteViewResponseSuccess, _GetAccountLevelServiceConfigurationResponseSuccess, _GetDefaultViewResponseSuccess, _GetIndexResponseSuccess, _GetManagedViewResponseSuccess, _GetResourceExplorerSetupResponseSuccess, _GetServiceIndexResponseSuccess, _GetServiceViewResponseSuccess, _GetViewResponseSuccess, _ListIndexesForMembersResponseSuccess, _ListIndexesResponseSuccess, _ListManagedViewsResponseSuccess, _ListResourcesResponseSuccess, _ListServiceIndexesResponseSuccess, _ListServiceViewsResponseSuccess, _ListStreamingAccessForServicesResponseSuccess, _ListSupportedResourceTypesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListViewsResponseSuccess, _SearchResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateIndexTypeResponseSuccess, _UpdateViewResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_default_view(params = {}) ⇒ Types::AssociateDefaultViewOutput
Sets the specified view as the default for the Amazon Web Services Region in which you call this operation.
-
#batch_get_view(params = {}) ⇒ Types::BatchGetViewOutput
Retrieves details about a list of views.
-
#create_index(params = {}) ⇒ Types::CreateIndexOutput
Turns on Amazon Web Services Resource Explorer in the Amazon Web Services Region in which you called this operation by creating an index.
-
#create_resource_explorer_setup(params = {}) ⇒ Types::CreateResourceExplorerSetupOutput
Creates a Resource Explorer setup configuration across multiple Amazon Web Services Regions.
-
#create_view(params = {}) ⇒ Types::CreateViewOutput
Creates a view that users can query by using the Search operation.
-
#delete_index(params = {}) ⇒ Types::DeleteIndexOutput
Deletes the specified index and turns off Amazon Web Services Resource Explorer in the specified Amazon Web Services Region.
-
#delete_resource_explorer_setup(params = {}) ⇒ Types::DeleteResourceExplorerSetupOutput
Deletes a Resource Explorer setup configuration.
-
#delete_view(params = {}) ⇒ Types::DeleteViewOutput
Deletes the specified view.
-
#disassociate_default_view(params = {}) ⇒ Struct
After you call this operation, the affected Amazon Web Services Region no longer has a default view.
-
#get_account_level_service_configuration(params = {}) ⇒ Types::GetAccountLevelServiceConfigurationOutput
Retrieves the status of your account's Amazon Web Services service access, and validates the service linked role required to access the multi-account search feature.
-
#get_default_view(params = {}) ⇒ Types::GetDefaultViewOutput
Retrieves the Amazon Resource Name (ARN) of the view that is the default for the Amazon Web Services Region in which you call this operation.
-
#get_index(params = {}) ⇒ Types::GetIndexOutput
Retrieves details about the Amazon Web Services Resource Explorer index in the Amazon Web Services Region in which you invoked the operation.
-
#get_managed_view(params = {}) ⇒ Types::GetManagedViewOutput
Retrieves details of the specified [Amazon Web Services-managed view][1].
-
#get_resource_explorer_setup(params = {}) ⇒ Types::GetResourceExplorerSetupOutput
Retrieves the status and details of a Resource Explorer setup operation.
-
#get_service_index(params = {}) ⇒ Types::GetServiceIndexOutput
Retrieves information about the Resource Explorer index in the current Amazon Web Services Region.
-
#get_service_view(params = {}) ⇒ Types::GetServiceViewOutput
Retrieves details about a specific Resource Explorer service view.
-
#get_view(params = {}) ⇒ Types::GetViewOutput
Retrieves details of the specified view.
-
#list_indexes(params = {}) ⇒ Types::ListIndexesOutput
Retrieves a list of all of the indexes in Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer.
-
#list_indexes_for_members(params = {}) ⇒ Types::ListIndexesForMembersOutput
Retrieves a list of a member's indexes in all Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer.
-
#list_managed_views(params = {}) ⇒ Types::ListManagedViewsOutput
Lists the Amazon resource names (ARNs) of the [Amazon Web Services-managed views][1] available in the Amazon Web Services Region in which you call this operation.
-
#list_resources(params = {}) ⇒ Types::ListResourcesOutput
Returns a list of resources and their details that match the specified criteria.
-
#list_service_indexes(params = {}) ⇒ Types::ListServiceIndexesOutput
Lists all Resource Explorer indexes across the specified Amazon Web Services Regions.
-
#list_service_views(params = {}) ⇒ Types::ListServiceViewsOutput
Lists all Resource Explorer service views available in the current Amazon Web Services account.
-
#list_streaming_access_for_services(params = {}) ⇒ Types::ListStreamingAccessForServicesOutput
Returns a list of Amazon Web Services services that have been granted streaming access to your Resource Explorer data.
-
#list_supported_resource_types(params = {}) ⇒ Types::ListSupportedResourceTypesOutput
Retrieves a list of all resource types currently supported by Amazon Web Services Resource Explorer.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags that are attached to the specified resource.
-
#list_views(params = {}) ⇒ Types::ListViewsOutput
Lists the [Amazon resource names (ARNs)][1] of the views available in the Amazon Web Services Region in which you call this operation.
-
#search(params = {}) ⇒ Types::SearchOutput
Searches for resources and displays details about all resources that match the specified criteria.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tag key and value pairs to an Amazon Web Services Resource Explorer view or index.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tag key and value pairs from an Amazon Web Services Resource Explorer view or index.
-
#update_index_type(params = {}) ⇒ Types::UpdateIndexTypeOutput
Changes the type of the index from one of the following types to the other.
-
#update_view(params = {}) ⇒ Types::UpdateViewOutput
Modifies some of the details of a view.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2291 2292 2293 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2291 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2294 2295 2296 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2294 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_default_view(params = {}) ⇒ Types::AssociateDefaultViewOutput
Sets the specified view as the default for the Amazon Web Services Region in which you call this operation. When a user performs a Search that doesn't explicitly specify which view to use, then Amazon Web Services Resource Explorer automatically chooses this default view for searches performed in this Amazon Web Services Region.
If an Amazon Web Services Region doesn't have a default view
configured, then users must explicitly specify a view with every
Search operation performed in that Region.
86 |
# File 'sig/client.rbs', line 86
def associate_default_view: (
|
#batch_get_view(params = {}) ⇒ Types::BatchGetViewOutput
Retrieves details about a list of views.
97 |
# File 'sig/client.rbs', line 97
def batch_get_view: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2264 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ResourceExplorer2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-resourceexplorer2' context[:gem_version] = '1.53.0' Seahorse::Client::Request.new(handlers, context) end |
#create_index(params = {}) ⇒ Types::CreateIndexOutput
Turns on Amazon Web Services Resource Explorer in the Amazon Web Services Region in which you called this operation by creating an index. Resource Explorer begins discovering the resources in this Region and stores the details about the resources in the index so that they can be queried by using the Search operation. You can create only one index in a Region.
For more details about what happens when you turn on Resource Explorer in an Amazon Web Services Region, see Turn on Resource Explorer to index your resources in an Amazon Web Services Region in the Amazon Web Services Resource Explorer User Guide.
If this is the first Amazon Web Services Region in which you've created an index for Resource Explorer, then this operation also creates a service-linked role in your Amazon Web Services account that allows Resource Explorer to enumerate your resources to populate the index.
-
Action:
resource-explorer-2:CreateIndexResource: The ARN of the index (as it will exist after the operation completes) in the Amazon Web Services Region and account in which you're trying to create the index. Use the wildcard character (
*) at the end of the string to match the eventual UUID. For example, the followingResourceelement restricts the role or user to creating an index in only theus-east-2Region of the specified account."Resource": "arn:aws:resource-explorer-2:us-west-2:<account-id>:index/*"Alternatively, you can use
"Resource": "*"to allow the role or user to create an index in any Region. -
Action:
iam:CreateServiceLinkedRoleResource: No specific resource (*).
This permission is required only the first time you create an index to turn on Resource Explorer in the account. Resource Explorer uses this to create the service-linked role needed to index the resources in your account. Resource Explorer uses the same service-linked role for all additional indexes you create afterwards.
109 |
# File 'sig/client.rbs', line 109
def create_index: (
|
#create_resource_explorer_setup(params = {}) ⇒ Types::CreateResourceExplorerSetupOutput
Creates a Resource Explorer setup configuration across multiple Amazon Web Services Regions. This operation sets up indexes and views in the specified Regions. This operation can also be used to set an aggregator Region for cross-Region resource search.
120 |
# File 'sig/client.rbs', line 120
def create_resource_explorer_setup: (
|
#create_view(params = {}) ⇒ Types::CreateViewOutput
Creates a view that users can query by using the Search operation.
Results from queries that you make using this view include only
resources that match the view's Filters. For more information about
Amazon Web Services Resource Explorer views, see Managing views
in the Amazon Web Services Resource Explorer User Guide.
Only the principals with an IAM identity-based policy that grants
Allow to the Search action on a Resource with the Amazon
resource name (ARN) of this view can Search using views you create
with this operation.
132 |
# File 'sig/client.rbs', line 132
def create_view: (
|
#delete_index(params = {}) ⇒ Types::DeleteIndexOutput
Deletes the specified index and turns off Amazon Web Services Resource
Explorer in the specified Amazon Web Services Region. When you delete
an index, Resource Explorer stops discovering and indexing resources
in that Region. Resource Explorer also deletes all views in that
Region. These actions occur as asynchronous background tasks. You can
check to see when the actions are complete by using the GetIndex
operation and checking the Status response value.
155 |
# File 'sig/client.rbs', line 155
def delete_index: (
|
#delete_resource_explorer_setup(params = {}) ⇒ Types::DeleteResourceExplorerSetupOutput
Deletes a Resource Explorer setup configuration. This operation removes indexes and views from the specified Regions or all Regions where Resource Explorer is configured.
165 |
# File 'sig/client.rbs', line 165
def delete_resource_explorer_setup: (
|
#delete_view(params = {}) ⇒ Types::DeleteViewOutput
Deletes the specified view.
If the specified view is the default view for its Amazon Web Services Region, then all Search operations in that Region must explicitly specify the view to use until you configure a new default by calling the AssociateDefaultView operation.
176 |
# File 'sig/client.rbs', line 176
def delete_view: (
|
#disassociate_default_view(params = {}) ⇒ Struct
After you call this operation, the affected Amazon Web Services Region no longer has a default view. All Search operations in that Region must explicitly specify a view or the operation fails. You can configure a new default by calling the AssociateDefaultView operation.
If an Amazon Web Services Region doesn't have a default view
configured, then users must explicitly specify a view with every
Search operation performed in that Region.
182 183 |
# File 'sig/client.rbs', line 182
def disassociate_default_view: () -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
|
#get_account_level_service_configuration(params = {}) ⇒ Types::GetAccountLevelServiceConfigurationOutput
Retrieves the status of your account's Amazon Web Services service access, and validates the service linked role required to access the multi-account search feature. Only the management account can invoke this API call.
190 191 |
# File 'sig/client.rbs', line 190
def get_account_level_service_configuration: () -> _GetAccountLevelServiceConfigurationResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetAccountLevelServiceConfigurationResponseSuccess
|
#get_default_view(params = {}) ⇒ Types::GetDefaultViewOutput
Retrieves the Amazon Resource Name (ARN) of the view that is the default for the Amazon Web Services Region in which you call this operation. You can then call GetView to retrieve the details of that view.
198 199 |
# File 'sig/client.rbs', line 198
def get_default_view: () -> _GetDefaultViewResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetDefaultViewResponseSuccess
|
#get_index(params = {}) ⇒ Types::GetIndexOutput
Retrieves details about the Amazon Web Services Resource Explorer index in the Amazon Web Services Region in which you invoked the operation.
213 214 |
# File 'sig/client.rbs', line 213
def get_index: () -> _GetIndexResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetIndexResponseSuccess
|
#get_managed_view(params = {}) ⇒ Types::GetManagedViewOutput
Retrieves details of the specified Amazon Web Services-managed view.
221 |
# File 'sig/client.rbs', line 221
def get_managed_view: (
|
#get_resource_explorer_setup(params = {}) ⇒ Types::GetResourceExplorerSetupOutput
Retrieves the status and details of a Resource Explorer setup operation. This operation returns information about the progress of creating or deleting Resource Explorer configurations across Regions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
232 |
# File 'sig/client.rbs', line 232
def get_resource_explorer_setup: (
|
#get_service_index(params = {}) ⇒ Types::GetServiceIndexOutput
Retrieves information about the Resource Explorer index in the current Amazon Web Services Region. This operation returns the ARN and type of the index if one exists.
245 246 |
# File 'sig/client.rbs', line 245
def get_service_index: () -> _GetServiceIndexResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetServiceIndexResponseSuccess
|
#get_service_view(params = {}) ⇒ Types::GetServiceViewOutput
Retrieves details about a specific Resource Explorer service view. This operation returns the configuration and properties of the specified view.
253 |
# File 'sig/client.rbs', line 253
def get_service_view: (
|
#get_view(params = {}) ⇒ Types::GetViewOutput
Retrieves details of the specified view.
264 |
# File 'sig/client.rbs', line 264
def get_view: (
|
#list_indexes(params = {}) ⇒ Types::ListIndexesOutput
Retrieves a list of all of the indexes in Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
275 |
# File 'sig/client.rbs', line 275
def list_indexes: (
|
#list_indexes_for_members(params = {}) ⇒ Types::ListIndexesForMembersOutput
Retrieves a list of a member's indexes in all Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer. Only the management account or a delegated administrator with service access enabled can invoke this API call.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
289 |
# File 'sig/client.rbs', line 289
def list_indexes_for_members: (
|
#list_managed_views(params = {}) ⇒ Types::ListManagedViewsOutput
Lists the Amazon resource names (ARNs) of the Amazon Web Services-managed views available in the Amazon Web Services Region in which you call this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
302 |
# File 'sig/client.rbs', line 302
def list_managed_views: (
|
#list_resources(params = {}) ⇒ Types::ListResourcesOutput
Returns a list of resources and their details that match the specified criteria. This query must use a view. If you don’t explicitly specify a view, then Resource Explorer uses the default view for the Amazon Web Services Region in which you call this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
316 |
# File 'sig/client.rbs', line 316
def list_resources: (
|
#list_service_indexes(params = {}) ⇒ Types::ListServiceIndexesOutput
Lists all Resource Explorer indexes across the specified Amazon Web Services Regions. This operation returns information about indexes including their ARNs, types, and Regions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
332 |
# File 'sig/client.rbs', line 332
def list_service_indexes: (
|
#list_service_views(params = {}) ⇒ Types::ListServiceViewsOutput
Lists all Resource Explorer service views available in the current Amazon Web Services account. This operation returns the ARNs of available service views.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
345 |
# File 'sig/client.rbs', line 345
def list_service_views: (
|
#list_streaming_access_for_services(params = {}) ⇒ Types::ListStreamingAccessForServicesOutput
Returns a list of Amazon Web Services services that have been granted streaming access to your Resource Explorer data. Streaming access allows Amazon Web Services services to receive real-time updates about your resources as they are indexed by Resource Explorer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
357 |
# File 'sig/client.rbs', line 357
def list_streaming_access_for_services: (
|
#list_supported_resource_types(params = {}) ⇒ Types::ListSupportedResourceTypesOutput
Retrieves a list of all resource types currently supported by Amazon Web Services Resource Explorer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
369 |
# File 'sig/client.rbs', line 369
def list_supported_resource_types: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags that are attached to the specified resource.
380 |
# File 'sig/client.rbs', line 380
def list_tags_for_resource: (
|
#list_views(params = {}) ⇒ Types::ListViewsOutput
Lists the Amazon resource names (ARNs) of the views available in the Amazon Web Services Region in which you call this operation.
NextToken response parameter for a null value
when calling a paginated operation. These operations can occasionally
return an empty set of results even when there are more results
available. The NextToken response parameter value is null only
when there are no more results to display.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
391 |
# File 'sig/client.rbs', line 391
def list_views: (
|
#search(params = {}) ⇒ Types::SearchOutput
Searches for resources and displays details about all resources that match the specified criteria. You must specify a query string.
All search queries must use a view. If you don't explicitly specify a
view, then Amazon Web Services Resource Explorer uses the default view
for the Amazon Web Services Region in which you call this operation.
The results are the logical intersection of the results that match
both the QueryString parameter supplied to this operation and the
SearchFilter parameter attached to the view.
For the complete syntax supported by the QueryString parameter, see
Search query syntax reference for Resource Explorer.
If your search results are empty, or are missing results that you think should be there, see Troubleshooting Resource Explorer search.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
405 |
# File 'sig/client.rbs', line 405
def search: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tag key and value pairs to an Amazon Web Services Resource Explorer view or index.
417 |
# File 'sig/client.rbs', line 417
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tag key and value pairs from an Amazon Web Services Resource Explorer view or index.
427 |
# File 'sig/client.rbs', line 427
def untag_resource: (
|
#update_index_type(params = {}) ⇒ Types::UpdateIndexTypeOutput
Changes the type of the index from one of the following types to the other. For more information about indexes and the role they perform in Amazon Web Services Resource Explorer, see Turning on cross-Region search by creating an aggregator index in the Amazon Web Services Resource Explorer User Guide.
-
AGGREGATORindex typeThe index contains information about resources from all Amazon Web Services Regions in the Amazon Web Services account in which you've created a Resource Explorer index. Resource information from all other Regions is replicated to this Region's index.
When you change the index type to
AGGREGATOR, Resource Explorer turns on replication of all discovered resource information from the other Amazon Web Services Regions in your account to this index. You can then, from this Region only, perform resource search queries that span all Amazon Web Services Regions in the Amazon Web Services account. Turning on replication from all other Regions is performed by asynchronous background tasks. You can check the status of the asynchronous tasks by using the GetIndex operation. When the asynchronous tasks complete, theStatusresponse of that operation changes fromUPDATINGtoACTIVE. After that, you can start to see results from other Amazon Web Services Regions in query results. However, it can take several hours for replication from all other Regions to complete.You can have only one aggregator index per Amazon Web Services account. Before you can promote a different index to be the aggregator index for the account, you must first demote the existing aggregator index to type
LOCAL. -
LOCALindex typeThe index contains information about resources in only the Amazon Web Services Region in which the index exists. If an aggregator index in another Region exists, then information in this local index is replicated to the aggregator index.
When you change the index type to
LOCAL, Resource Explorer turns off the replication of resource information from all other Amazon Web Services Regions in the Amazon Web Services account to this Region. The aggregator index remains in theUPDATINGstate until all replication with other Regions successfully stops. You can check the status of the asynchronous task by using the GetIndex operation. When Resource Explorer successfully stops all replication with other Regions, theStatusresponse of that operation changes fromUPDATINGtoACTIVE. Separately, the resource information from other Regions that was previously stored in the index is deleted within 30 days by another background task. Until that asynchronous task completes, some results from other Regions can continue to appear in search results.After you demote an aggregator index to a local index, you must wait 24 hours before you can promote another index to be the new aggregator index for the account.
441 |
# File 'sig/client.rbs', line 441
def update_index_type: (
|
#update_view(params = {}) ⇒ Types::UpdateViewOutput
Modifies some of the details of a view. You can change the filter string and the list of included properties. You can't change the name of the view.
452 |
# File 'sig/client.rbs', line 452
def update_view: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2284 2285 2286 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2284 def waiter_names [] end |