Class: Aws::ResourceExplorer2::Types::GetDefaultViewOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResourceExplorer2::Types::GetDefaultViewOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resourceexplorer2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#view_arn ⇒ String
The [Amazon resource name (ARN)][1] of the view that is the current default for the Amazon Web Services Region in which you called this operation.
Instance Attribute Details
#view_arn ⇒ String
The Amazon resource name (ARN) of the view that is the current default for the Amazon Web Services Region in which you called this operation.
509 510 511 512 513 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 509 class GetDefaultViewOutput < Struct.new( :view_arn) SENSITIVE = [] include Aws::Structure end |