Class: Aws::ResourceExplorer2::Types::Resource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resourceexplorer2/types.rb

Overview

A resource in Amazon Web Services that Amazon Web Services Resource Explorer has discovered, and for which it has stored information in the index of the Amazon Web Services Region that contains the resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon resource name (ARN) of the resource.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1663

class Resource < Struct.new(
  :arn,
  :owning_account_id,
  :region,
  :resource_type,
  :service,
  :cfn_resource_type,
  :last_reported_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#cfn_resource_typeString

The CloudFormation resource type identifier for the resource, such as AWS::EC2::Instance or AWS::S3::Bucket.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1663

class Resource < Struct.new(
  :arn,
  :owning_account_id,
  :region,
  :resource_type,
  :service,
  :cfn_resource_type,
  :last_reported_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#last_reported_atTime

The date and time that Resource Explorer last queried this resource and updated the index with the latest information about the resource.

Returns:

  • (Time)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1663

class Resource < Struct.new(
  :arn,
  :owning_account_id,
  :region,
  :resource_type,
  :service,
  :cfn_resource_type,
  :last_reported_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#owning_account_idString

The Amazon Web Services account that owns the resource.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1663

class Resource < Struct.new(
  :arn,
  :owning_account_id,
  :region,
  :resource_type,
  :service,
  :cfn_resource_type,
  :last_reported_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesArray<Types::ResourceProperty>

A structure with additional type-specific details about the resource. These properties can be added by turning on integration between Resource Explorer and other Amazon Web Services services.

Returns:



1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1663

class Resource < Struct.new(
  :arn,
  :owning_account_id,
  :region,
  :resource_type,
  :service,
  :cfn_resource_type,
  :last_reported_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region in which the resource was created and exists.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1663

class Resource < Struct.new(
  :arn,
  :owning_account_id,
  :region,
  :resource_type,
  :service,
  :cfn_resource_type,
  :last_reported_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1663

class Resource < Struct.new(
  :arn,
  :owning_account_id,
  :region,
  :resource_type,
  :service,
  :cfn_resource_type,
  :last_reported_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The Amazon Web Services service that owns the resource and is responsible for creating and updating it.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1663

class Resource < Struct.new(
  :arn,
  :owning_account_id,
  :region,
  :resource_type,
  :service,
  :cfn_resource_type,
  :last_reported_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end