Class: Aws::ResourceExplorer2::Types::SearchOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResourceExplorer2::Types::SearchOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resourceexplorer2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Types::ResourceCount
The number of resources that match the query.
-
#next_token ⇒ String
If present, indicates that more output is available than is included in the current response.
-
#resources ⇒ Array<Types::Resource>
The list of structures that describe the resources that match the query.
-
#view_arn ⇒ String
The [Amazon resource name (ARN)][1] of the view that this operation used to perform the search.
Instance Attribute Details
#count ⇒ Types::ResourceCount
The number of resources that match the query.
1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1872 class SearchOutput < Struct.new( :resources, :next_token, :view_arn, :count) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If present, indicates that more output is available than is included
in the current response. Use this value in the NextToken request
parameter in a subsequent call to the operation to get the next part
of the output. You should repeat this until the NextToken response
element comes back as null. The pagination tokens expire after 24
hours.
1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1872 class SearchOutput < Struct.new( :resources, :next_token, :view_arn, :count) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::Resource>
The list of structures that describe the resources that match the query.
1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1872 class SearchOutput < Struct.new( :resources, :next_token, :view_arn, :count) SENSITIVE = [] include Aws::Structure end |
#view_arn ⇒ String
The Amazon resource name (ARN) of the view that this operation used to perform the search.
1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1872 class SearchOutput < Struct.new( :resources, :next_token, :view_arn, :count) SENSITIVE = [] include Aws::Structure end |