Class: Aws::ResourceExplorer2::Types::UpdateIndexTypeOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resourceexplorer2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon resource name (ARN) of the index that you updated.

Returns:

  • (String)


2167
2168
2169
2170
2171
2172
2173
2174
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2167

class UpdateIndexTypeOutput < Struct.new(
  :arn,
  :type,
  :state,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and timestamp when the index was last updated.

Returns:

  • (Time)


2167
2168
2169
2170
2171
2172
2173
2174
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2167

class UpdateIndexTypeOutput < Struct.new(
  :arn,
  :type,
  :state,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Indicates the state of the request to update the index. This operation is asynchronous. Call the GetIndex operation to check for changes.

Returns:

  • (String)


2167
2168
2169
2170
2171
2172
2173
2174
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2167

class UpdateIndexTypeOutput < Struct.new(
  :arn,
  :type,
  :state,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Specifies the type of the specified index after the operation completes.

Returns:

  • (String)


2167
2168
2169
2170
2171
2172
2173
2174
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2167

class UpdateIndexTypeOutput < Struct.new(
  :arn,
  :type,
  :state,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end