Class: Aws::ResourceExplorer2::Types::ViewStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resourceexplorer2/types.rb

Overview

Contains information about the status of a Resource Explorer view operation in a specific Region.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_detailsTypes::ErrorDetails

Details about any error that occurred during the view operation.

Returns:



2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2370

class ViewStatus < Struct.new(
  :status,
  :view,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the view operation. Valid values are SUCCEEDED, FAILED, IN_PROGRESS, or SKIPPED.

Returns:

  • (String)


2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2370

class ViewStatus < Struct.new(
  :status,
  :view,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#viewTypes::View

A view is a structure that defines a set of filters that provide a view into the information in the Amazon Web Services Resource Explorer index. The filters specify which information from the index is visible to the users of the view. For example, you can specify filters that include only resources that are tagged with the key "ENV" and the value "DEVELOPMENT" in the results returned by this view. You could also create a second view that includes only resources that are tagged with "ENV" and "PRODUCTION".

Returns:



2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2370

class ViewStatus < Struct.new(
  :status,
  :view,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end