Class: Aws::ResourceExplorer2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ResourceExplorer2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-resourceexplorer2/client.rb
Overview
An API client for ResourceExplorer2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ResourceExplorer2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_default_view(params = {}) ⇒ Types::AssociateDefaultViewOutput
Sets the specified view as the default for the Amazon Web Services Region in which you call this operation.
-
#batch_get_view(params = {}) ⇒ Types::BatchGetViewOutput
Retrieves details about a list of views.
-
#create_index(params = {}) ⇒ Types::CreateIndexOutput
Turns on Amazon Web Services Resource Explorer in the Amazon Web Services Region in which you called this operation by creating an index.
-
#create_resource_explorer_setup(params = {}) ⇒ Types::CreateResourceExplorerSetupOutput
Creates a Resource Explorer setup configuration across multiple Amazon Web Services Regions.
-
#create_view(params = {}) ⇒ Types::CreateViewOutput
Creates a view that users can query by using the Search operation.
-
#delete_index(params = {}) ⇒ Types::DeleteIndexOutput
Deletes the specified index and turns off Amazon Web Services Resource Explorer in the specified Amazon Web Services Region.
-
#delete_resource_explorer_setup(params = {}) ⇒ Types::DeleteResourceExplorerSetupOutput
Deletes a Resource Explorer setup configuration.
-
#delete_view(params = {}) ⇒ Types::DeleteViewOutput
Deletes the specified view.
-
#disassociate_default_view(params = {}) ⇒ Struct
After you call this operation, the affected Amazon Web Services Region no longer has a default view.
-
#get_account_level_service_configuration(params = {}) ⇒ Types::GetAccountLevelServiceConfigurationOutput
Retrieves the status of your account’s Amazon Web Services service access, and validates the service linked role required to access the multi-account search feature.
-
#get_default_view(params = {}) ⇒ Types::GetDefaultViewOutput
Retrieves the Amazon Resource Name (ARN) of the view that is the default for the Amazon Web Services Region in which you call this operation.
-
#get_index(params = {}) ⇒ Types::GetIndexOutput
Retrieves details about the Amazon Web Services Resource Explorer index in the Amazon Web Services Region in which you invoked the operation.
-
#get_managed_view(params = {}) ⇒ Types::GetManagedViewOutput
Retrieves details of the specified [Amazon Web Services-managed view].
-
#get_resource_explorer_setup(params = {}) ⇒ Types::GetResourceExplorerSetupOutput
Retrieves the status and details of a Resource Explorer setup operation.
-
#get_service_index(params = {}) ⇒ Types::GetServiceIndexOutput
Retrieves information about the Resource Explorer index in the current Amazon Web Services Region.
-
#get_service_view(params = {}) ⇒ Types::GetServiceViewOutput
Retrieves details about a specific Resource Explorer service view.
-
#get_view(params = {}) ⇒ Types::GetViewOutput
Retrieves details of the specified view.
-
#list_indexes(params = {}) ⇒ Types::ListIndexesOutput
Retrieves a list of all of the indexes in Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer.
-
#list_indexes_for_members(params = {}) ⇒ Types::ListIndexesForMembersOutput
Retrieves a list of a member’s indexes in all Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer.
-
#list_managed_views(params = {}) ⇒ Types::ListManagedViewsOutput
Lists the Amazon resource names (ARNs) of the [Amazon Web Services-managed views] available in the Amazon Web Services Region in which you call this operation.
-
#list_resources(params = {}) ⇒ Types::ListResourcesOutput
Returns a list of resources and their details that match the specified criteria.
-
#list_service_indexes(params = {}) ⇒ Types::ListServiceIndexesOutput
Lists all Resource Explorer indexes across the specified Amazon Web Services Regions.
-
#list_service_views(params = {}) ⇒ Types::ListServiceViewsOutput
Lists all Resource Explorer service views available in the current Amazon Web Services account.
-
#list_streaming_access_for_services(params = {}) ⇒ Types::ListStreamingAccessForServicesOutput
Returns a list of Amazon Web Services services that have been granted streaming access to your Resource Explorer data.
-
#list_supported_resource_types(params = {}) ⇒ Types::ListSupportedResourceTypesOutput
Retrieves a list of all resource types currently supported by Amazon Web Services Resource Explorer.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags that are attached to the specified resource.
-
#list_views(params = {}) ⇒ Types::ListViewsOutput
Lists the [Amazon resource names (ARNs)] of the views available in the Amazon Web Services Region in which you call this operation.
-
#search(params = {}) ⇒ Types::SearchOutput
Searches for resources and displays details about all resources that match the specified criteria.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tag key and value pairs to an Amazon Web Services Resource Explorer view or index.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tag key and value pairs from an Amazon Web Services Resource Explorer view or index.
-
#update_index_type(params = {}) ⇒ Types::UpdateIndexTypeOutput
Changes the type of the index from one of the following types to the other.
-
#update_view(params = {}) ⇒ Types::UpdateViewOutput
Modifies some of the details of a view.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2284 2285 2286 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2284 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2287 2288 2289 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2287 def errors_module Errors end |
Instance Method Details
#associate_default_view(params = {}) ⇒ Types::AssociateDefaultViewOutput
Sets the specified view as the default for the Amazon Web Services Region in which you call this operation. When a user performs a Search that doesn’t explicitly specify which view to use, then Amazon Web Services Resource Explorer automatically chooses this default view for searches performed in this Amazon Web Services Region.
If an Amazon Web Services Region doesn’t have a default view configured, then users must explicitly specify a view with every ‘Search` operation performed in that Region.
515 516 517 518 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 515 def associate_default_view(params = {}, = {}) req = build_request(:associate_default_view, params) req.send_request() end |
#batch_get_view(params = {}) ⇒ Types::BatchGetViewOutput
Retrieves details about a list of views.
560 561 562 563 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 560 def batch_get_view(params = {}, = {}) req = build_request(:batch_get_view, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2257 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ResourceExplorer2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-resourceexplorer2' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#create_index(params = {}) ⇒ Types::CreateIndexOutput
Turns on Amazon Web Services Resource Explorer in the Amazon Web Services Region in which you called this operation by creating an index. Resource Explorer begins discovering the resources in this Region and stores the details about the resources in the index so that they can be queried by using the Search operation. You can create only one index in a Region.
<note markdown=“1”> This operation creates only a local index. To promote the local index in one Amazon Web Services Region into the aggregator index for the Amazon Web Services account, use the UpdateIndexType operation. For more information, see [Turning on cross-Region search by creating an aggregator index] in the *Amazon Web Services Resource Explorer User Guide*.
</note>
For more details about what happens when you turn on Resource Explorer in an Amazon Web Services Region, see [Turn on Resource Explorer to index your resources in an Amazon Web Services Region] in the *Amazon Web Services Resource Explorer User Guide*.
If this is the first Amazon Web Services Region in which you’ve created an index for Resource Explorer, then this operation also
- creates a service-linked role][3
-
in your Amazon Web Services account
that allows Resource Explorer to enumerate your resources to populate the index.
-
Action: ‘resource-explorer-2:CreateIndex`
Resource: The ARN of the index (as it will exist after the operation completes) in the Amazon Web Services Region and account in which you’re trying to create the index. Use the wildcard character (‘*`) at the end of the string to match the eventual UUID. For example, the following `Resource` element restricts the role or user to creating an index in only the `us-east-2` Region of the specified account.
‘“Resource”: “arn:aws:resource-explorer-2:us-west-2:<account-id>:index/*”`
Alternatively, you can use ‘“Resource”: “*”` to allow the role or user to create an index in any Region.
-
Action: ‘iam:CreateServiceLinkedRole`
Resource: No specific resource (*).
This permission is required only the first time you create an index to turn on Resource Explorer in the account. Resource Explorer uses this to create the [service-linked role needed to index the resources in your account]. Resource Explorer uses the same service-linked role for all additional indexes you create afterwards.
[1]: docs.aws.amazon.com/resource-explorer/latest/userguide/manage-aggregator-region.html [2]: docs.aws.amazon.com/resource-explorer/latest/userguide/manage-service-activate.html [3]: docs.aws.amazon.com/resource-explorer/latest/userguide/security_iam_service-linked-roles.html
668 669 670 671 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 668 def create_index(params = {}, = {}) req = build_request(:create_index, params) req.send_request() end |
#create_resource_explorer_setup(params = {}) ⇒ Types::CreateResourceExplorerSetupOutput
Creates a Resource Explorer setup configuration across multiple Amazon Web Services Regions. This operation sets up indexes and views in the specified Regions. This operation can also be used to set an aggregator Region for cross-Region resource search.
713 714 715 716 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 713 def create_resource_explorer_setup(params = {}, = {}) req = build_request(:create_resource_explorer_setup, params) req.send_request() end |
#create_view(params = {}) ⇒ Types::CreateViewOutput
Creates a view that users can query by using the Search operation. Results from queries that you make using this view include only resources that match the view’s ‘Filters`. For more information about Amazon Web Services Resource Explorer views, see [Managing views] in the *Amazon Web Services Resource Explorer User Guide*.
Only the principals with an IAM identity-based policy that grants ‘Allow` to the `Search` action on a `Resource` with the [Amazon resource name (ARN)] of this view can Search using views you create with this operation.
[1]: docs.aws.amazon.com/resource-explorer/latest/userguide/manage-views.html [2]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
831 832 833 834 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 831 def create_view(params = {}, = {}) req = build_request(:create_view, params) req.send_request() end |
#delete_index(params = {}) ⇒ Types::DeleteIndexOutput
Deletes the specified index and turns off Amazon Web Services Resource Explorer in the specified Amazon Web Services Region. When you delete an index, Resource Explorer stops discovering and indexing resources in that Region. Resource Explorer also deletes all views in that Region. These actions occur as asynchronous background tasks. You can check to see when the actions are complete by using the GetIndex operation and checking the ‘Status` response value.
<note markdown=“1”> If the index you delete is the aggregator index for the Amazon Web Services account, you must wait 24 hours before you can promote another local index to be the aggregator index for the account. Users can’t perform account-wide searches using Resource Explorer until another aggregator index is configured.
</note>
882 883 884 885 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 882 def delete_index(params = {}, = {}) req = build_request(:delete_index, params) req.send_request() end |
#delete_resource_explorer_setup(params = {}) ⇒ Types::DeleteResourceExplorerSetupOutput
Deletes a Resource Explorer setup configuration. This operation removes indexes and views from the specified Regions or all Regions where Resource Explorer is configured.
921 922 923 924 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 921 def delete_resource_explorer_setup(params = {}, = {}) req = build_request(:delete_resource_explorer_setup, params) req.send_request() end |
#delete_view(params = {}) ⇒ Types::DeleteViewOutput
Deletes the specified view.
If the specified view is the default view for its Amazon Web Services Region, then all Search operations in that Region must explicitly specify the view to use until you configure a new default by calling the AssociateDefaultView operation.
959 960 961 962 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 959 def delete_view(params = {}, = {}) req = build_request(:delete_view, params) req.send_request() end |
#disassociate_default_view(params = {}) ⇒ Struct
After you call this operation, the affected Amazon Web Services Region no longer has a default view. All Search operations in that Region must explicitly specify a view or the operation fails. You can configure a new default by calling the AssociateDefaultView operation.
If an Amazon Web Services Region doesn’t have a default view configured, then users must explicitly specify a view with every ‘Search` operation performed in that Region.
979 980 981 982 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 979 def disassociate_default_view(params = {}, = {}) req = build_request(:disassociate_default_view, params) req.send_request() end |
#get_account_level_service_configuration(params = {}) ⇒ Types::GetAccountLevelServiceConfigurationOutput
Retrieves the status of your account’s Amazon Web Services service access, and validates the service linked role required to access the multi-account search feature. Only the management account can invoke this API call.
1002 1003 1004 1005 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1002 def get_account_level_service_configuration(params = {}, = {}) req = build_request(:get_account_level_service_configuration, params) req.send_request() end |
#get_default_view(params = {}) ⇒ Types::GetDefaultViewOutput
Retrieves the Amazon Resource Name (ARN) of the view that is the default for the Amazon Web Services Region in which you call this operation. You can then call GetView to retrieve the details of that view.
1024 1025 1026 1027 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1024 def get_default_view(params = {}, = {}) req = build_request(:get_default_view, params) req.send_request() end |
#get_index(params = {}) ⇒ Types::GetIndexOutput
Retrieves details about the Amazon Web Services Resource Explorer index in the Amazon Web Services Region in which you invoked the operation.
1062 1063 1064 1065 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1062 def get_index(params = {}, = {}) req = build_request(:get_index, params) req.send_request() end |
#get_managed_view(params = {}) ⇒ Types::GetManagedViewOutput
Retrieves details of the specified [Amazon Web Services-managed view].
[1]: docs.aws.amazon.com/resource-explorer/latest/userguide/aws-managed-views.html
1105 1106 1107 1108 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1105 def get_managed_view(params = {}, = {}) req = build_request(:get_managed_view, params) req.send_request() end |
#get_resource_explorer_setup(params = {}) ⇒ Types::GetResourceExplorerSetupOutput
Retrieves the status and details of a Resource Explorer setup operation. This operation returns information about the progress of creating or deleting Resource Explorer configurations across Regions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1169 1170 1171 1172 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1169 def get_resource_explorer_setup(params = {}, = {}) req = build_request(:get_resource_explorer_setup, params) req.send_request() end |
#get_service_index(params = {}) ⇒ Types::GetServiceIndexOutput
Retrieves information about the Resource Explorer index in the current Amazon Web Services Region. This operation returns the ARN and type of the index if one exists.
1192 1193 1194 1195 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1192 def get_service_index(params = {}, = {}) req = build_request(:get_service_index, params) req.send_request() end |
#get_service_view(params = {}) ⇒ Types::GetServiceViewOutput
Retrieves details about a specific Resource Explorer service view. This operation returns the configuration and properties of the specified view.
1229 1230 1231 1232 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1229 def get_service_view(params = {}, = {}) req = build_request(:get_service_view, params) req.send_request() end |
#get_view(params = {}) ⇒ Types::GetViewOutput
Retrieves details of the specified view.
1272 1273 1274 1275 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1272 def get_view(params = {}, = {}) req = build_request(:get_view, params) req.send_request() end |
#list_indexes(params = {}) ⇒ Types::ListIndexesOutput
Retrieves a list of all of the indexes in Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1342 1343 1344 1345 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1342 def list_indexes(params = {}, = {}) req = build_request(:list_indexes, params) req.send_request() end |
#list_indexes_for_members(params = {}) ⇒ Types::ListIndexesForMembersOutput
Retrieves a list of a member’s indexes in all Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer. Only the management account or a delegated administrator with service access enabled can invoke this API call.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1408 1409 1410 1411 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1408 def list_indexes_for_members(params = {}, = {}) req = build_request(:list_indexes_for_members, params) req.send_request() end |
#list_managed_views(params = {}) ⇒ Types::ListManagedViewsOutput
Lists the Amazon resource names (ARNs) of the [Amazon Web Services-managed views] available in the Amazon Web Services Region in which you call this operation.
[1]: docs.aws.amazon.com/resource-explorer/latest/userguide/aws-managed-views.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1473 1474 1475 1476 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1473 def list_managed_views(params = {}, = {}) req = build_request(:list_managed_views, params) req.send_request() end |
#list_resources(params = {}) ⇒ Types::ListResourcesOutput
Returns a list of resources and their details that match the specified criteria. This query must use a view. If you don’t explicitly specify a view, then Resource Explorer uses the default view for the Amazon Web Services Region in which you call this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1581 1582 1583 1584 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1581 def list_resources(params = {}, = {}) req = build_request(:list_resources, params) req.send_request() end |
#list_service_indexes(params = {}) ⇒ Types::ListServiceIndexesOutput
Lists all Resource Explorer indexes across the specified Amazon Web Services Regions. This operation returns information about indexes including their ARNs, types, and Regions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1629 1630 1631 1632 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1629 def list_service_indexes(params = {}, = {}) req = build_request(:list_service_indexes, params) req.send_request() end |
#list_service_views(params = {}) ⇒ Types::ListServiceViewsOutput
Lists all Resource Explorer service views available in the current Amazon Web Services account. This operation returns the ARNs of available service views.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1670 1671 1672 1673 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1670 def list_service_views(params = {}, = {}) req = build_request(:list_service_views, params) req.send_request() end |
#list_streaming_access_for_services(params = {}) ⇒ Types::ListStreamingAccessForServicesOutput
Returns a list of Amazon Web Services services that have been granted streaming access to your Resource Explorer data. Streaming access allows Amazon Web Services services to receive real-time updates about your resources as they are indexed by Resource Explorer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1720 1721 1722 1723 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1720 def list_streaming_access_for_services(params = {}, = {}) req = build_request(:list_streaming_access_for_services, params) req.send_request() end |
#list_supported_resource_types(params = {}) ⇒ Types::ListSupportedResourceTypesOutput
Retrieves a list of all resource types currently supported by Amazon Web Services Resource Explorer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1776 1777 1778 1779 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1776 def list_supported_resource_types(params = {}, = {}) req = build_request(:list_supported_resource_types, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags that are attached to the specified resource.
1810 1811 1812 1813 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1810 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_views(params = {}) ⇒ Types::ListViewsOutput
Lists the [Amazon resource names (ARNs)] of the views available in the Amazon Web Services Region in which you call this operation.
<note markdown=“1”> Always check the ‘NextToken` response parameter for a `null` value when calling a paginated operation. These operations can occasionally return an empty set of results even when there are more results available. The `NextToken` response parameter value is `null` only when there are no more results to display.
</note>
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1877 1878 1879 1880 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1877 def list_views(params = {}, = {}) req = build_request(:list_views, params) req.send_request() end |
#search(params = {}) ⇒ Types::SearchOutput
Searches for resources and displays details about all resources that match the specified criteria. You must specify a query string.
All search queries must use a view. If you don’t explicitly specify a view, then Amazon Web Services Resource Explorer uses the default view for the Amazon Web Services Region in which you call this operation. The results are the logical intersection of the results that match both the ‘QueryString` parameter supplied to this operation and the `SearchFilter` parameter attached to the view.
For the complete syntax supported by the ‘QueryString` parameter, see [Search query syntax reference for Resource Explorer].
If your search results are empty, or are missing results that you think should be there, see [Troubleshooting Resource Explorer search].
[1]: docs.aws.amazon.com/resource-explorer/latest/APIReference/about-query-syntax.html [2]: docs.aws.amazon.com/resource-explorer/latest/userguide/troubleshooting_search.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1999 2000 2001 2002 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 1999 def search(params = {}, = {}) req = build_request(:search, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tag key and value pairs to an Amazon Web Services Resource Explorer view or index.
2030 2031 2032 2033 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2030 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tag key and value pairs from an Amazon Web Services Resource Explorer view or index.
2059 2060 2061 2062 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2059 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_index_type(params = {}) ⇒ Types::UpdateIndexTypeOutput
Changes the type of the index from one of the following types to the other. For more information about indexes and the role they perform in Amazon Web Services Resource Explorer, see [Turning on cross-Region search by creating an aggregator index] in the *Amazon Web Services Resource Explorer User Guide*.
-
AGGREGATORindex typeThe index contains information about resources from all Amazon Web Services Regions in the Amazon Web Services account in which you’ve created a Resource Explorer index. Resource information from all other Regions is replicated to this Region’s index.
When you change the index type to ‘AGGREGATOR`, Resource Explorer turns on replication of all discovered resource information from the other Amazon Web Services Regions in your account to this index. You can then, from this Region only, perform resource search queries that span all Amazon Web Services Regions in the Amazon Web Services account. Turning on replication from all other Regions is performed by asynchronous background tasks. You can check the status of the asynchronous tasks by using the GetIndex operation. When the asynchronous tasks complete, the `Status` response of that operation changes from `UPDATING` to `ACTIVE`. After that, you can start to see results from other Amazon Web Services Regions in query results. However, it can take several hours for replication from all other Regions to complete.
You can have only one aggregator index per Amazon Web Services account. Before you can promote a different index to be the aggregator index for the account, you must first demote the existing aggregator index to type ‘LOCAL`.
-
LOCALindex typeThe index contains information about resources in only the Amazon Web Services Region in which the index exists. If an aggregator index in another Region exists, then information in this local index is replicated to the aggregator index.
When you change the index type to ‘LOCAL`, Resource Explorer turns off the replication of resource information from all other Amazon Web Services Regions in the Amazon Web Services account to this Region. The aggregator index remains in the `UPDATING` state until all replication with other Regions successfully stops. You can check the status of the asynchronous task by using the GetIndex operation. When Resource Explorer successfully stops all replication with other Regions, the `Status` response of that operation changes from `UPDATING` to `ACTIVE`. Separately, the resource information from other Regions that was previously stored in the index is deleted within 30 days by another background task. Until that asynchronous task completes, some results from other Regions can continue to appear in search results.
After you demote an aggregator index to a local index, you must wait 24 hours before you can promote another index to be the new aggregator index for the account.
[1]: docs.aws.amazon.com/resource-explorer/latest/userguide/manage-aggregator-region.html
2167 2168 2169 2170 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2167 def update_index_type(params = {}, = {}) req = build_request(:update_index_type, params) req.send_request() end |
#update_view(params = {}) ⇒ Types::UpdateViewOutput
Modifies some of the details of a view. You can change the filter string and the list of included properties. You can’t change the name of the view.
2248 2249 2250 2251 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2248 def update_view(params = {}, = {}) req = build_request(:update_view, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2277 2278 2279 |
# File 'lib/aws-sdk-resourceexplorer2/client.rb', line 2277 def waiter_names [] end |