Class: Aws::ResourceExplorer2::Types::ServiceView
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResourceExplorer2::Types::ServiceView
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resourceexplorer2/types.rb
Overview
Contains the configuration and properties of a Resource Explorer service view.
Constant Summary collapse
- SENSITIVE =
[:filters]
Instance Attribute Summary collapse
-
#filters ⇒ Types::SearchFilter
A search filter defines which resources can be part of a search query result set.
-
#included_properties ⇒ Array<Types::IncludedProperty>
A list of additional resource properties that are included in this view for search and filtering purposes.
-
#scope_type ⇒ String
The scope type of the service view, which determines what resources are included.
-
#service_linked_recorder ⇒ Types::ServiceLinkedRecorderInfo
Information about the service-linked recorder associated with this service view.
-
#service_view_arn ⇒ String
The Amazon Resource Name (ARN) of the service view.
-
#service_view_name ⇒ String
The name of the service view.
-
#streaming_access_for_service ⇒ String
The Amazon Web Services service that has streaming access to this view's data.
Instance Attribute Details
#filters ⇒ Types::SearchFilter
A search filter defines which resources can be part of a search query result set.
1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1972 class ServiceView < Struct.new( :service_view_arn, :service_view_name, :filters, :included_properties, :streaming_access_for_service, :scope_type, :service_linked_recorder) SENSITIVE = [:filters] include Aws::Structure end |
#included_properties ⇒ Array<Types::IncludedProperty>
A list of additional resource properties that are included in this view for search and filtering purposes.
1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1972 class ServiceView < Struct.new( :service_view_arn, :service_view_name, :filters, :included_properties, :streaming_access_for_service, :scope_type, :service_linked_recorder) SENSITIVE = [:filters] include Aws::Structure end |
#scope_type ⇒ String
The scope type of the service view, which determines what resources are included.
1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1972 class ServiceView < Struct.new( :service_view_arn, :service_view_name, :filters, :included_properties, :streaming_access_for_service, :scope_type, :service_linked_recorder) SENSITIVE = [:filters] include Aws::Structure end |
#service_linked_recorder ⇒ Types::ServiceLinkedRecorderInfo
Information about the service-linked recorder associated with this service view. When a service view is paired with a service-linked recorder, Resource Explorer uses the recorder's resource type list to filter search results and streaming data.
1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1972 class ServiceView < Struct.new( :service_view_arn, :service_view_name, :filters, :included_properties, :streaming_access_for_service, :scope_type, :service_linked_recorder) SENSITIVE = [:filters] include Aws::Structure end |
#service_view_arn ⇒ String
The Amazon Resource Name (ARN) of the service view.
1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1972 class ServiceView < Struct.new( :service_view_arn, :service_view_name, :filters, :included_properties, :streaming_access_for_service, :scope_type, :service_linked_recorder) SENSITIVE = [:filters] include Aws::Structure end |
#service_view_name ⇒ String
The name of the service view.
1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1972 class ServiceView < Struct.new( :service_view_arn, :service_view_name, :filters, :included_properties, :streaming_access_for_service, :scope_type, :service_linked_recorder) SENSITIVE = [:filters] include Aws::Structure end |
#streaming_access_for_service ⇒ String
The Amazon Web Services service that has streaming access to this view's data.
1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 1972 class ServiceView < Struct.new( :service_view_arn, :service_view_name, :filters, :included_properties, :streaming_access_for_service, :scope_type, :service_linked_recorder) SENSITIVE = [:filters] include Aws::Structure end |