Class: Aws::ResourceExplorer2::Types::UpdateViewInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResourceExplorer2::Types::UpdateViewInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resourceexplorer2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:filters]
Instance Attribute Summary collapse
-
#filters ⇒ Types::SearchFilter
An array of strings that specify which resources are included in the results of queries made using this view.
-
#included_properties ⇒ Array<Types::IncludedProperty>
Specifies optional fields that you want included in search results from this view.
-
#view_arn ⇒ String
The [Amazon resource name (ARN)][1] of the view that you want to modify.
Instance Attribute Details
#filters ⇒ Types::SearchFilter
An array of strings that specify which resources are included in the
results of queries made using this view. When you use this view in a
Search operation, the filter string is combined with the search's
QueryString parameter using a logical AND operator.
For information about the supported syntax, see Search query reference for Resource Explorer in the Amazon Web Services Resource Explorer User Guide.
This query string in the context of this operation supports only
filter prefixes with optional operators. It doesn't
support free-form text. For example, the string region:us* service:ec2 -tag:stage=prod includes all Amazon EC2 resources in
any Amazon Web Services Region that begins with the letters us and
is not tagged with a key Stage that has the value prod.
2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2220 class UpdateViewInput < Struct.new( :view_arn, :included_properties, :filters) SENSITIVE = [:filters] include Aws::Structure end |
#included_properties ⇒ Array<Types::IncludedProperty>
Specifies optional fields that you want included in search results from this view. It is a list of objects that each describe a field to include.
The default is an empty list, with no optional fields included in the results.
2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2220 class UpdateViewInput < Struct.new( :view_arn, :included_properties, :filters) SENSITIVE = [:filters] include Aws::Structure end |
#view_arn ⇒ String
The Amazon resource name (ARN) of the view that you want to modify.
2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2220 class UpdateViewInput < Struct.new( :view_arn, :included_properties, :filters) SENSITIVE = [:filters] include Aws::Structure end |