Class: Aws::ResourceExplorer2::Types::ViewStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResourceExplorer2::Types::ViewStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resourceexplorer2/types.rb
Overview
Contains information about the status of a Resource Explorer view operation in a specific Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_details ⇒ Types::ErrorDetails
Details about any error that occurred during the view operation.
-
#status ⇒ String
The current status of the view operation.
-
#view ⇒ Types::View
A view is a structure that defines a set of filters that provide a view into the information in the Amazon Web Services Resource Explorer index.
Instance Attribute Details
#error_details ⇒ Types::ErrorDetails
Details about any error that occurred during the view operation.
2322 2323 2324 2325 2326 2327 2328 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2322 class ViewStatus < Struct.new( :status, :view, :error_details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the view operation. Valid values are SUCCEEDED, FAILED, IN_PROGRESS, or SKIPPED.
2322 2323 2324 2325 2326 2327 2328 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2322 class ViewStatus < Struct.new( :status, :view, :error_details) SENSITIVE = [] include Aws::Structure end |
#view ⇒ Types::View
A view is a structure that defines a set of filters that provide a view into the information in the Amazon Web Services Resource Explorer index. The filters specify which information from the index is visible to the users of the view. For example, you can specify filters that include only resources that are tagged with the key “ENV” and the value “DEVELOPMENT” in the results returned by this view. You could also create a second view that includes only resources that are tagged with “ENV” and “PRODUCTION”.
2322 2323 2324 2325 2326 2327 2328 |
# File 'lib/aws-sdk-resourceexplorer2/types.rb', line 2322 class ViewStatus < Struct.new( :status, :view, :error_details) SENSITIVE = [] include Aws::Structure end |